# Welcome to geomind


[![image](https://img.shields.io/pypi/v/geomind.svg)](https://pypi.python.org/pypi/geomind)


**Geoai package**


-   Free software: MIT License
-   Documentation: <https://Iamnyatichi.github.io/geomind>
    

## Features

-   TODO
